@@ -64,6 +64,18 @@ def read_bytes(file_name, start_num, size, is_image=True):
         image = Image.open(io.BytesIO(image))
     return image
 
+
+def save_image_bytes(file_name, start_num, size, savename):
+    try:
+        x = read_bytes(file_name, start_num, size)
+        with open(savename, 'wb') as f:
+            f.write(x)
+        return True
+    except Exception as e:
+        print(e)
+        return False
+
+
 def read_json(file_path):
     d = open(file_path).read().split('\n')
     res = []
